@@ -6,7 +6,7 @@ use warnings;
 sub _croak ($;@) { require Error::TypeTiny; goto \&Error::TypeTiny::croak }
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '1.012005';
+our $VERSION   = '1.016010';
 
 $VERSION =~ tr/_//d;
 
@@ -89,7 +89,8 @@ Evaluate: {
 		}
 		
 		if ( $node->{type} eq "slurpy" ) {
-			return +{ slurpy => _eval_type( $node->{of}, $reg ) };
+			require Types::Standard;
+			return Types::Standard::Slurpy()->of( _eval_type( $node->{of}, $reg ) );
 		}
 		
 		if ( $node->{type} eq "complement" ) {
@@ -590,7 +591,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2021 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2022 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
