@@ -11,7 +11,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Tiny::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Tiny::VERSION    = '1.012005';
+	$Type::Tiny::VERSION    = '1.016010';
 	$Type::Tiny::XS_VERSION = '0.016';
 }
 
@@ -21,6 +21,8 @@ $Type::Tiny::XS_VERSION =~ tr/_//d;
 use Scalar::Util qw( blessed );
 use Types::TypeTiny ();
 
+our $SafePackage = sprintf 'package %s;', __PACKAGE__;
+
 sub _croak ($;@) { require Error::TypeTiny; goto \&Error::TypeTiny::croak }
 
 sub _swap { $_[2] ? @_[ 1, 0 ] : @_[ 0, 1 ] }
@@ -153,6 +155,7 @@ __PACKAGE__->_install_overloads(
 	},
 	q(eq)  => sub { "$_[0]" eq "$_[1]" },
 	q(cmp) => sub { $_[2] ? ( "$_[1]" cmp "$_[0]" ) : ( "$_[0]" cmp "$_[1]" ) },
+	q(0+)  => sub { $_[0]{uniq} },
 );
 
 __PACKAGE__->_install_overloads(
@@ -414,10 +417,11 @@ sub _dd {
 } #/ sub _dd
 
 sub _loose_to_TypeTiny {
+	my $caller = caller( 1 ); # assumption
 	map +(
 		ref( $_ )
 		? Types::TypeTiny::to_TypeTiny( $_ )
-		: do { require Type::Utils; Type::Utils::dwim_type( $_ ) }
+		: do { require Type::Utils; Type::Utils::dwim_type( $_, for => $caller ) }
 	), @_;
 }
 
@@ -436,14 +440,14 @@ sub inlined              { $_[0]{inlined} }
 sub deprecated           { $_[0]{deprecated} }
 sub constraint_generator { $_[0]{constraint_generator} }
 sub inline_generator     { $_[0]{inline_generator} }
-sub name_generator { $_[0]{name_generator} ||= $_[0]->_build_name_generator }
-sub coercion_generator { $_[0]{coercion_generator} }
-sub parameters         { $_[0]{parameters} }
-sub moose_type         { $_[0]{moose_type} ||= $_[0]->_build_moose_type }
-sub mouse_type         { $_[0]{mouse_type} ||= $_[0]->_build_mouse_type }
-sub deep_explanation   { $_[0]{deep_explanation} }
-sub my_methods         { $_[0]{my_methods} ||= $_[0]->_build_my_methods }
-sub sorter             { $_[0]{sorter} }
+sub name_generator       { $_[0]{name_generator} ||= $_[0]->_build_name_generator }
+sub coercion_generator   { $_[0]{coercion_generator} }
+sub parameters           { $_[0]{parameters} }
+sub moose_type           { $_[0]{moose_type} ||= $_[0]->_build_moose_type }
+sub mouse_type           { $_[0]{mouse_type} ||= $_[0]->_build_mouse_type }
+sub deep_explanation     { $_[0]{deep_explanation} }
+sub my_methods           { $_[0]{my_methods} ||= $_[0]->_build_my_methods }
+sub sorter               { $_[0]{sorter} }
 
 sub has_parent               { exists $_[0]{parent} }
 sub has_library              { exists $_[0]{library} }
@@ -512,7 +516,7 @@ sub _build_default_message {
 sub _build_name_generator {
 	my $self = shift;
 	return sub {
-		my ( $s, @a ) = @_;
+		s/[\x00-\x1F]//smg for ( my ( $s, @a ) = @_ );
 		sprintf( '%s[%s]', $s, join q[,], @a );
 	};
 }
@@ -597,7 +601,7 @@ push @CMP, sub {
 		Scalar::Util::refaddr( $B_stem->compiled_check );
 		
 	if ( $A_stem->can_be_inlined and $B_stem->can_be_inlined ) {
-		return 0
+		return CMP_EQUIVALENT
 			if $A_stem->inline_check( '$WOLFIE' ) eq $B_stem->inline_check( '$WOLFIE' );
 	}
 	
@@ -797,7 +801,8 @@ sub validate_explain {
 		my $deep = $self->parent->deep_explanation->( $self, $value, $varname );
 		return [ $message, @$deep ] if $deep;
 	}
-	
+
+	local $SIG{__WARN__} = sub {};
 	return [
 		$message,
 		sprintf( '"%s" is defined as: %s', $self, $self->_perlcode )
@@ -877,7 +882,7 @@ sub inline_check {
 	}
 	my $r = join " && " => map {
 		/[;{}]/ && !/\Ado \{.+\}\z/
-			? "do { package Type::Tiny; $_ }"
+			? "do { $SafePackage $_ }"
 			: "($_)"
 	} @r;
 	return @r == 1 ? $r : "($r)";
@@ -928,8 +933,8 @@ sub inline_assert {
 	} #/ else [ if ( $typevarname ) ]
 	
 	$do_wrapper
-		? qq[do { no warnings "void"; package Type::Tiny; $inline_check or $inline_throw; $varname };]
-		: qq[     no warnings "void"; package Type::Tiny; $inline_check or $inline_throw; $varname   ];
+		? qq[do { no warnings "void"; $SafePackage $inline_check or $inline_throw; $varname };]
+		: qq[     no warnings "void"; $SafePackage $inline_check or $inline_throw; $varname   ];
 } #/ sub inline_assert
 
 sub _failed_check {
@@ -940,9 +945,11 @@ sub _failed_check {
 	
 	my $exception_class =
 		delete( $attrs{exception_class} ) || "Error::TypeTiny::Assertion";
-		
+	my $callback = delete( $attrs{on_die} );
+
 	if ( $self ) {
-		$exception_class->throw(
+		return $exception_class->throw_cb(
+			$callback,
 			message => $self->get_message( $value ),
 			type    => $self,
 			value   => $value,
@@ -950,9 +957,9 @@ sub _failed_check {
 		);
 	}
 	else {
-		$exception_class->throw(
-			message =>
-				sprintf( '%s did not pass type constraint "%s"', _dd( $value ), $name ),
+		return $exception_class->throw_cb(
+			$callback,
+			message => sprintf( '%s did not pass type constraint "%s"', _dd( $value ), $name ),
 			value => $value,
 			%attrs,
 		);
@@ -2411,6 +2418,15 @@ if it needs to rely on callbacks when asked not to.)
 
 Most normal users can ignore this.
 
+=item C<< $Type::Tiny::SafePackage >>
+
+This is the string "package Type::Tiny;" which is sometimes inserted
+into strings of inlined code to avoid namespace clashes. In most cases,
+you do not need to change this. However, if you are inlining type
+constraint code, saving that code into Perl modules, and uploading them
+to CPAN, you may wish to change it to avoid problems with the CPAN
+indexer. Most normal users of Type::Tiny do not need to be aware of this.
+
 =back
 
 =head2 Environment
@@ -2462,7 +2478,7 @@ Thanks to Matt S Trout for advice on L<Moo> integration.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2013-2014, 2017-2021 by Toby Inkster.
+This software is copyright (c) 2013-2014, 2017-2022 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
